@@ -1,25 +1,27 @@
-;; Support for Harvard Citation style package for AUC-TeX
-;;      Harvard citation style is from Peter Williams
-;;      available on the CTAN servers
+;;; harvard.el --- Support for Harvard Citation style package for AUCTeX.
 
-;; Version: $Id: harvard.el,v 1.11 2008/07/23 07:22:52 stephent Exp $
+;; Copyright (C) 1994, 1997, 2005 Free Software Foundation, Inc.
 
-;; Copyright (C) 1994 Berwin Turlach <berwin@core.ucl.ac.be>
-;; Copyright (C) 1997 Berwin Turlach <berwin.turlach@anu.edu.au>
+;; Author: Berwin Turlach <statba@nus.edu.sg>
+;; Maintainer: auctex-devel@gnu.org
+;; Keywords: tex
 
-;; This program is free software; you can redistribute it and/or modify
-;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 1, or (at your option)
+;; This file is part of AUCTeX.
+
+;; AUCTeX is free software; you can redistribute it and/or modify it
+;; under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 3, or (at your option)
 ;; any later version.
-;; 
-;; This program is distributed in the hope that it will be useful,
-;; but WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-;; GNU General Public License for more details.
-;; 
+
+;; AUCTeX is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; General Public License for more details.
+
 ;; You should have received a copy of the GNU General Public License
-;; along with this program; if not, write to the Free Software
-;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+;; along with AUCTeX; see the file COPYING.  If not, write to the Free
+;; Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+;; 02110-1301, USA.
 
 ;;; Code:
 
@@ -98,7 +100,11 @@
     
     (setq LaTeX-item-list
 	  (cons '("thebibliography" . LaTeX-item-harvardbib)
-		LaTeX-item-list)))))
+		LaTeX-item-list))
+
+    ;; Tell RefTeX
+    (when (fboundp 'reftex-set-cite-format)
+      (reftex-set-cite-format 'harvard)))))
 
 (defun LaTeX-env-harvardbib (environment &optional ignore)
   "Insert ENVIRONMENT with label for harvarditem."
@@ -114,4 +120,9 @@
   "Insert a new harvarditem."
   (TeX-insert-macro "harvarditem"))
 
+(defvar LaTeX-harvard-package-options '("full" "abbr" "default"
+					"agsmcite" "dcucite" "round"
+					"curly" "angle" "square" "none")
+  "Package options for the harvard package.")
+
 ;; harvard.el ends here
