@@ -1,11 +1,10 @@
 ;;; virtex.el - Common code for all TeX formats.
 
-;; $Id: virtex.el,v 1.10 2008/07/23 07:22:58 stephent Exp $
+;; Author: Per Abrahamsen <abraham@dina.kvl.dk>
 
 ;;; Code:
 
 (TeX-add-style-hook "virtex"
- (function
   (lambda ()
     (TeX-add-symbols "/" "above" "abovedisplayshortskip"
 		     "abovedisplayskip" "abovewithdelims" "accent"
@@ -78,6 +77,6 @@
 		     "vcenter" "vfil" "vfill" "vfilneg" "vfuzz"
 		     "voffset" "vrule" "vsize" "vskip" "vss" "vtop"
 		     "wd" "widowpenalty" "write" "xdef" "xleaders"
-		     "xspaceskip" "year"))))
+		     "xspaceskip" "year")))
 
 ;;; virtex.el ends here
